@@ -1,18 +1,17 @@
-from zope.i18nmessageid import MessageFactory
 import zc.sourcefactory.basic
 import pycountry
 
-iso3166msg = MessageFactory('iso3166')
-
+import gocept.country.db
 
 class CountrySource(zc.sourcefactory.basic.BasicSourceFactory):
     """Source for the pycountry countries."""
 
     def getValues(self):
-        return iter(pycountry.countries)
+        for country in pycountry.countries:
+            yield gocept.country.db.Country(country.alpha2)
 
     def getTitle(self, value):
-        return iso3166msg(value.name)
+        return value.name
 
     def getToken(self, value):
         return value.alpha2
@@ -22,10 +21,11 @@ class ScriptSource(zc.sourcefactory.basic.BasicSourceFactory):
     """Source for the pycountry scripts."""
 
     def getValues(self):
-        return iter(pycountry.scripts)
+        for script in pycountry.scripts:
+            yield gocept.country.db.Script(script.alpha4)
 
     def getTitle(self, value):
-        return iso3166msg(value.name)
+        return value.name
 
     def getToken(self, value):
         return value.alpha4
@@ -35,10 +35,11 @@ class CurrencySource(zc.sourcefactory.basic.BasicSourceFactory):
     """Source for the pycountry currencies."""
 
     def getValues(self):
-        return iter(pycountry.currencies)
+        for currency in pycountry.currencies:
+            yield gocept.country.db.Currency(currency.letter)
 
     def getTitle(self, value):
-        return iso3166msg(value.name)
+        return value.name
 
     def getToken(self, value):
         return value.letter
@@ -48,13 +49,14 @@ class LanguageSource(zc.sourcefactory.basic.BasicSourceFactory):
     """Source for the pycountry languages."""
 
     def getValues(self):
-        return iter(pycountry.languages)
+        for language in pycountry.languages:
+            yield gocept.country.db.Language(language.bibliographic)
 
     def getTitle(self, value):
-        return iso3166msg(value.name)
+        return value.name
 
     def getToken(self, value):
-        return value.alpha2
+        return value.bibliographic
 
 
 countries = CountrySource()
